.. _development-page:

=========================
 Development & Community
=========================

PyMetrology is an open-source project, and relies on its community of users to keep getting better.

PyMetrology source code and issues are managed on `Github <https://github.com/FabriceSalvaire/PyMetrology>`_.

**Note to Packagers: Please don't create PyMetrology package (PiPY do the job)**

How you can help ?
------------------

As an open source project, anyone is welcome to contribute in whatever form they are able.

.. , which can include taking part in discussions, filing bug reports, proposing improvements,
   contributing code or documentation, and testing it.

* Promote PyMetrology on the web and all around you
* Fill bug reports
* Test PyMetrology on Linux, Windows and OS X
* Check for errors on the documentation
* Propose improvements
* Implement missing features
* Provides additional examples

Contributors
------------

The list of contributors is available at https://github.com/FabriceSalvaire/PyMetrology/graphs/contributors
